/**
 * \file list-mon-spells.h
 * \brief List of monster spell flags 
 *
 * Changing flag order will break savefiles.  Flags
 * below start from 0 on line 20, so a flag's sequence number is its line
 * number minus 20. Up to and including BOULDER are "innate" spells.
 *
 * Fields:
 * name - spell name
 * type - spell type
 * desc - textual description
 * msgt - flag for message colouring
 * save - does this spell allow a saving throw?
 * verb - description of attack
 * blind_verb - description of unseen attacks
 * lore_desc - description used in monster recall
 */
/* 	name		type					desc				msgt			save	verb					blind_verb			lore_desc*/
RSF(NONE,		0,						NULL,				0,				FALSE,	NULL,					NULL,				"")
RSF(SHRIEK,		RST_ANNOY,				"shriek",			MSG_SHRIEK,		FALSE,	"makes a high-pitched",	"shrieks",			"shriek for help")
RSF(ARROW_1,	RST_BOLT,				"arrow",			0,				FALSE,	"fires an",				"fires an arrow",	"fire an arrow")
RSF(ARROW_2,	RST_BOLT,				"arrow",			0,				FALSE,	"fires an",				"fires an arrow",	"fire arrows")
RSF(ARROW_3,	RST_BOLT,				"missile",			0,				FALSE,	"fires a",				"fires a missile",	"fire a missile")
RSF(ARROW_4,	RST_BOLT,				"missile",			0,				FALSE,	"fires a",				"fires a missile",	"fire missiles")
RSF(BR_ACID,	RST_BREATH,				"acid",				MSG_BR_ACID,	FALSE,	"breathes",				"hisses",			"acid")
RSF(BR_ELEC,	RST_BREATH,				"lightning",		MSG_BR_ELEC,	FALSE,	"breathes",				"crackles",			"lightning")
RSF(BR_FIRE,	RST_BREATH,				"fire",				MSG_BR_FIRE,	FALSE,	"breathes",				"roars",			"fire")
RSF(BR_COLD,	RST_BREATH,				"frost",			MSG_BR_FROST,	FALSE,	"breathes",				"wooshes",			"frost")
RSF(BR_POIS,	RST_BREATH,				"poison",			MSG_BR_GAS,		FALSE,	"breathes",				"retches",			"poison")
RSF(BR_NETH,	RST_BREATH,				"nether",			MSG_BR_NETHER,	FALSE,	"breathes",				"groans",			"nether")
RSF(BR_LIGHT,	RST_BREATH,				"light",			MSG_BR_LIGHT,	FALSE,	"breathes",				"breathes",			"light")
RSF(BR_DARK,	RST_BREATH,				"darkness",			MSG_BR_DARK,	FALSE,	"breathes",				"breathes",			"darkness")
RSF(BR_SOUN,	RST_BREATH,				"sound",			MSG_BR_SOUND,	FALSE,	"breathes",				"breathes",			"sound")
RSF(BR_CHAO,	RST_BREATH,				"chaos",			MSG_BR_CHAOS,	FALSE,	"breathes",				"breathes",			"chaos")
RSF(BR_DISE,	RST_BREATH,				"disenchantment",	MSG_BR_DISEN,	FALSE,	"breathes",				"breathes",			"disenchantment")
RSF(BR_NEXU,	RST_BREATH,				"nexus",			MSG_BR_NEXUS,	FALSE,	"breathes",				"breathes",			"nexus")
RSF(BR_TIME,	RST_BREATH,				"time",				MSG_BR_TIME,	FALSE,	"breathes",				"breathes",			"time")
RSF(BR_INER,	RST_BREATH,				"inertia",			MSG_BR_INERTIA,	FALSE,	"breathes",				"breathes",			"inertia")
RSF(BR_GRAV,	RST_BREATH,				"gravity",			MSG_BR_GRAVITY,	FALSE,	"breathes",				"breathes",			"gravity")
RSF(BR_SHAR,	RST_BREATH,				"shards",			MSG_BR_SHARDS,	FALSE,	"breathes",				"breathes",			"shards")
RSF(BR_PLAS,	RST_BREATH,				"plasma",			MSG_BR_PLASMA,	FALSE,	"breathes",				"breathes",			"plasma")
RSF(BR_WALL,	RST_BREATH,				"force",			MSG_BR_FORCE,	FALSE,	"breathes",				"breathes",			"force")
RSF(BR_MANA,	RST_BREATH,				"raw magic",		0,				FALSE,	"breathes",				"breathes",			"mana")
RSF(BOULDER,	RST_BOLT,				"boulder",			0,				FALSE,	"hurls a",				"hurls a boulder",	"throw boulders")
RSF(BA_ACID,	RST_BALL,				"acid",				0,				FALSE,	"casts a ball of",		"mumbles",			"produce acid balls")
RSF(BA_ELEC,	RST_BALL,				"lightning",		0,				FALSE,	"casts a ball of",		"mumbles",			"produce lightning balls")
RSF(BA_FIRE,	RST_BALL,				"fire",				0,				FALSE,	"casts a ball of",		"mumbles",			"produce fire balls")
RSF(BA_COLD,	RST_BALL,				"frost",			0,				FALSE,	"casts a ball of",		"mumbles",			"produce frost balls")
RSF(BA_POIS,	RST_BALL,				"poison",			0,				FALSE,	"creates a cloud of",	"mumbles",			"produce poison balls")
RSF(BA_NETH,	RST_BALL,				"nether",			0,				FALSE,	"casts a ball of",		"mumbles",			"produce nether balls")
RSF(BA_WATE,	RST_BALL,				"water",			0,				FALSE,	"creates a whirlpool of","gurgles",			"produce water balls")
RSF(BA_MANA,	RST_BALL,				"raw magic",		0,				FALSE,	"invokes a storm of",	"screams loudly",	"invoke mana storms")
RSF(BA_DARK,	RST_BALL,				"darkness",			0,				FALSE,	"invokes a storm of",	"mumbles loudly",	"invoke darkness storms")
RSF(DRAIN_MANA,	RST_ANNOY,				"mana away",		0,				FALSE,	"drains your",			"moans",			"drain mana")
RSF(MIND_BLAST,	RST_ATTACK | RST_ANNOY,	"psionic energy",	0,				TRUE,	"gazes at you with",	"focuses on your mind",	"cause mind blasting")
RSF(BRAIN_SMASH,RST_ATTACK | RST_ANNOY,	"psionic energy",	0,				TRUE,	"smashes you with",		"focuses on your mind",	"cause brain smashing")
RSF(CAUSE_1,	RST_ATTACK,				"curses",			0,				TRUE,	"points at you and",	"mumbles",			"cause light wounds")
RSF(CAUSE_2,	RST_ATTACK,				"curses horribly",	0,				TRUE,	"points at you and",	"mumbles",			"cause serious wounds")
RSF(CAUSE_3,	RST_ATTACK,				"incants terribly",	0,				TRUE,	"points at you and",	"mumbles loudly",	"cause critical wounds")
RSF(CAUSE_4,	RST_ATTACK,				"screams the word 'DIE!'",0,		TRUE,	"points at you and",	"screams the word 'DIE!'",	"cause mortal wounds")
RSF(BO_ACID,	RST_BOLT,				"acid",				0,				FALSE,	"casts a bolt of",		"mumbles",			"produce acid bolts")
RSF(BO_ELEC,	RST_BOLT,				"lightning",		0,				FALSE,	"casts a bolt of",		"mumbles",			"produce lightning bolts")
RSF(BO_FIRE,	RST_BOLT,				"fire",				0,				FALSE,	"casts a bolt of",		"mumbles",			"produce fire bolts")
RSF(BO_COLD,	RST_BOLT,				"frost",			0,				FALSE,	"casts a bolt of",		"mumbles",			"produce frost bolts")
RSF(BO_POIS,	RST_BOLT,				"poison",			0,				FALSE,	"spews a stream of",	"retches",			"produce poison bolts")
RSF(BO_NETH,	RST_BOLT,				"nether",			0,				FALSE,	"casts a bolt of",		"mumbles",			"produce nether bolts")
RSF(BO_WATE,	RST_BOLT,				"water",			0,				FALSE,	"fires a jet of",		"gurgles",			"produce water bolts")
RSF(BO_MANA,	RST_BOLT,				"raw magic",		0,				FALSE,	"casts a bolt of",		"screams",			"produce mana bolts")
RSF(BO_PLAS,	RST_BOLT,				"plasma",			0,				FALSE,	"casts a bolt of",		"screams",			"produce plasma bolts")
RSF(BO_ICEE,	RST_BOLT,				"ice",				0,				FALSE,	"shoots a spear of",	"mumbles",			"produce ice bolts")
RSF(MISSILE,	RST_BOLT,				"magic missile",	0,				FALSE,	"fires a",				"mumbles",			"produce magic missiles")
RSF(SCARE,		RST_ANNOY,				"scary horrors",	MSG_CAST_FEAR,	TRUE,	"conjures up",			"makes scary noises",	"terrify")
RSF(BLIND,		RST_ANNOY,				"blinding flash",	0,				TRUE,	"sets off a",			"mumbles",			"blind")
RSF(CONF,		RST_ANNOY,				"weird things",		0,				TRUE,	"conjures up",			"messes with your mind",	"confuse")
RSF(SLOW,		RST_ANNOY | RST_HASTE,	"move slowly",		0,				TRUE,	"tries to make you",	"mumbles",			"slow")
RSF(HOLD,		RST_ANNOY | RST_HASTE,	"stop moving",		0,				TRUE,	"tries to make you",	"mumbles",			"paralyze")
RSF(HASTE,		RST_HASTE,				"moving faster",	0,				FALSE,	"starts",				"mumbles",			"haste-self")
RSF(HEAL,		RST_HEAL,				"closing wounds",	0,				FALSE,	"magically starts",		"mumbles",			"heal-self")
RSF(BLINK,		RST_TACTIC | RST_ESCAPE,"phase door",		0,				FALSE,	"casts a",				"mumbles",			"blink-self")
RSF(TPORT,		RST_ESCAPE,				"teleport away",	0,				FALSE,	"tries to",				"makes a soft 'pop'",	"teleport-self")
RSF(TELE_TO,	RST_ANNOY,				"come hither",		MSG_TELEPORT,	FALSE,	"commands you to",		"commands you to come hither",	"teleport to")
RSF(TELE_AWAY,	RST_ESCAPE,				"go away",			MSG_TELEPORT,	FALSE,	"commands you to",		"commands you to go away",	"teleport away")
RSF(TELE_LEVEL,	RST_ESCAPE,				"go far away",		MSG_TPLEVEL,	TRUE,	"commands you to",		"commands you to go far away",	"teleport level")
RSF(DARKNESS,	RST_ANNOY,				"darkness",			0,				FALSE,	"surrounds you in",		"mumbles",			"create darkness")
RSF(TRAPS,		RST_ANNOY,				"traps",			MSG_CREATE_TRAP,FALSE,	"cackles evilly about",	"cackles evilly",	"create traps")
RSF(FORGET,		RST_ANNOY,				"forget things",	0,				TRUE,	"tries to make you",	"messes with your mind",	"cause amnesia")
RSF(S_KIN,		RST_SUMMON,				"its kin",			MSG_SUM_MONSTER,FALSE,	"summons",				"mumbles",			"summon similar monsters")
RSF(S_HI_DEMON,	RST_SUMMON,				"major demons",		MSG_SUM_HI_DEMON,FALSE,	"summons",				"mumbles",			"summon greater demons")
RSF(S_MONSTER,	RST_SUMMON,				"a companion",		MSG_SUM_MONSTER,FALSE,	"summons",				"mumbles",			"summon a monster")
RSF(S_MONSTERS,	RST_SUMMON,				"some friends",		MSG_SUM_MONSTER,FALSE,	"summons",				"mumbles",			"summon monsters")
RSF(S_ANIMAL,	RST_SUMMON,				"animals",			MSG_SUM_ANIMAL,	FALSE,	"summons",				"mumbles",			"summon animals")
RSF(S_SPIDER,	RST_SUMMON,				"spiders",			MSG_SUM_SPIDER,	FALSE,	"summons",				"mumbles",			"summon spiders")
RSF(S_HOUND,	RST_SUMMON,				"hounds",			MSG_SUM_HOUND,	FALSE,	"summons",				"mumbles",			"summon hounds")
RSF(S_HYDRA,	RST_SUMMON,				"hydrae",			MSG_SUM_HYDRA,	FALSE,	"summons",				"mumbles",			"summon hydras")
RSF(S_AINU,		RST_SUMMON,				"an ainu",			MSG_SUM_AINU,	FALSE,	"summons",				"mumbles",			"summon an ainu")
RSF(S_DEMON,	RST_SUMMON,				"a demon",			MSG_SUM_DEMON,	FALSE,	"summons",				"mumbles",			"summon a demon")
RSF(S_UNDEAD,	RST_SUMMON,				"the undead",		MSG_SUM_UNDEAD,	FALSE,	"summons",				"mumbles",			"summon an undead")
RSF(S_DRAGON,	RST_SUMMON,				"a dragon",			MSG_SUM_DRAGON,	FALSE,	"summons",				"mumbles",			"summon a dragon")
RSF(S_HI_UNDEAD,RST_SUMMON,				"fiends of darkness",MSG_SUM_HI_UNDEAD,FALSE,"summons",				"mumbles",			"summon greater undead")
RSF(S_HI_DRAGON,RST_SUMMON,				"ancient dragons",	MSG_SUM_HI_DRAGON,FALSE,"summons",				"mumbles",			"summon ancient dragons")
RSF(S_WRAITH,	RST_SUMMON,				"ringwraiths",		MSG_SUM_WRAITH,	FALSE,	"summons",				"mumbles",			"summon ringwraiths")
RSF(S_UNIQUE,	RST_SUMMON,				"his servants",		MSG_SUM_UNIQUE,	FALSE,	"summons",				"mumbles",			"summon uniques")
RSF(MAX,		0,						NULL,				0,				FALSE,	NULL,					NULL,				"")
